@@ -88,6 +88,12 @@ void AsyncFizzClientT<SM>::connect(
   if (pskIdentity) {
     cachedPsk = fizzContext_->getPsk(*pskIdentity);
   }
+
+  auto echPolicy = fizzContext_->getECHPolicy();
+  if (!echConfigs && echPolicy && sni.hasValue()) {
+    echConfigs = echPolicy->getConfig(sni.value());
+  }
+
   fizzClient_.connect(
       fizzContext_,
       std::move(verifier),
@@ -294,6 +300,7 @@ void AsyncFizzClientT<SM>::writeAppData(
     folly::AsyncTransportWrapper::WriteCallback* callback,
     std::unique_ptr<folly::IOBuf>&& buf,
     folly::WriteFlags flags) {
+  DelayedDestruction::DestructorGuard dg(this);
   if (!good()) {
     if (callback) {
       callback->writeErr(
@@ -357,7 +364,7 @@ void AsyncFizzClientT<SM>::writeAppData(
       // it is, then flush them
       pendingHandshakeAppWrites_.push_back(std::move(w));
     } else {
-      fizzClient_.appWrite(std::move(w));
+      performAppWrite(std::move(w));
     }
   }
 }
@@ -502,7 +509,7 @@ AsyncFizzClientT<SM>::handleEarlyReject() {
         if (!earlyDataState_->resendBuffer.empty()) {
           AppWrite resend;
           resend.data = earlyDataState_->resendBuffer.move();
-          fizzClient_.appWrite(std::move(resend));
+          performAppWrite(std::move(resend));
         }
       } else {
         return folly::AsyncSocketException(
@@ -515,6 +522,13 @@ AsyncFizzClientT<SM>::handleEarlyReject() {
   return folly::none;
 }
 
+template <typename SM>
+void AsyncFizzClientT<SM>::performAppWrite(AppWrite w) {
+  auto size = w.data->computeChainDataLength();
+  fizzClient_.appWrite(std::move(w));
+  wroteApplicationBytes(size);
+}
+
 template <typename SM>
 void AsyncFizzClientT<SM>::ActionMoveVisitor::operator()(
     ReportHandshakeSuccess& success) {
@@ -530,7 +544,7 @@ void AsyncFizzClientT<SM>::ActionMoveVisitor::operator()(
   while (!pendingHandshakeAppWrites.empty()) {
     auto w = std::move(pendingHandshakeAppWrites.front());
     pendingHandshakeAppWrites.pop_front();
-    client_.fizzClient_.appWrite(std::move(w));
+    client_.performAppWrite(std::move(w));
   }
 
   if (client_.earlyDataState_) {
@@ -549,7 +563,7 @@ void AsyncFizzClientT<SM>::ActionMoveVisitor::operator()(
     while (!client_.earlyDataState_->pendingAppWrites.empty()) {
       auto w = std::move(client_.earlyDataState_->pendingAppWrites.front());
       client_.earlyDataState_->pendingAppWrites.pop_front();
-      client_.fizzClient_.appWrite(std::move(w));
+      client_.performAppWrite(std::move(w));
     }
     client_.earlyDataState_.clear();
   }
