@@ -187,8 +187,8 @@ std::string toString(CipherSuite cipher) {
       return "TLS_CHACHA20_POLY1305_SHA256";
     case CipherSuite::TLS_AES_128_OCB_SHA256_EXPERIMENTAL:
       return "TLS_AES_128_OCB_SHA256_EXPERIMENTAL";
-    case CipherSuite::TLS_AEGIS_256_SHA384:
-      return "TLS_AEGIS_256_SHA384";
+    case CipherSuite::TLS_AEGIS_256_SHA512:
+      return "TLS_AEGIS_256_SHA512";
     case CipherSuite::TLS_AEGIS_128L_SHA256:
       return "TLS_AEGIS_128L_SHA256";
   }
@@ -251,8 +251,6 @@ std::string toString(NamedGroup group) {
       return "x25519";
     case NamedGroup::secp521r1_x25519:
       return "secp521r1_x25519";
-    case NamedGroup::secp384r1_bikel3:
-      return "secp384r1_bikel3";
     case NamedGroup::x25519_kyber512:
       return "x25519_kyber512";
     case NamedGroup::secp256r1_kyber512:
