@@ -21,6 +21,7 @@
 #include <fizz/extensions/tokenbinding/TokenBindingClientExtension.h>
 #include <fizz/extensions/tokenbinding/TokenBindingContext.h>
 #include <fizz/extensions/tokenbinding/TokenBindingServerExtension.h>
+#include <fizz/protocol/OpenSSLSelfCertImpl.h>
 #include <fizz/protocol/test/Matchers.h>
 #include <fizz/protocol/test/Utilities.h>
 #include <fizz/server/AsyncFizzServer.h>
@@ -71,7 +72,7 @@ class HandshakeTest : public Test {
     std::vector<ssl::X509UniquePtr> rsaCerts;
     rsaCerts.emplace_back(getCert(kRSACertificate));
     certManager->addCert(
-        std::make_shared<SelfCertImpl<KeyType::RSA>>(
+        std::make_shared<OpenSSLSelfCertImpl<KeyType::RSA>>(
             getPrivateKey(kRSAKey), std::move(rsaCerts), compressors),
         true);
     std::vector<ssl::X509UniquePtr> p256Certs;
@@ -80,11 +81,11 @@ class HandshakeTest : public Test {
     p256Certs.emplace_back(getCert(kP256Certificate));
     p384Certs.emplace_back(getCert(kP384Certificate));
     p521Certs.emplace_back(getCert(kP521Certificate));
-    certManager->addCert(std::make_shared<SelfCertImpl<KeyType::P256>>(
+    certManager->addCert(std::make_shared<OpenSSLSelfCertImpl<KeyType::P256>>(
         getPrivateKey(kP256Key), std::move(p256Certs), compressors));
-    certManager->addCert(std::make_shared<SelfCertImpl<KeyType::P384>>(
+    certManager->addCert(std::make_shared<OpenSSLSelfCertImpl<KeyType::P384>>(
         getPrivateKey(kP384Key), std::move(p384Certs), compressors));
-    certManager->addCert(std::make_shared<SelfCertImpl<KeyType::P521>>(
+    certManager->addCert(std::make_shared<OpenSSLSelfCertImpl<KeyType::P521>>(
         getPrivateKey(kP521Key), std::move(p521Certs), compressors));
     serverContext_->setCertManager(certManager);
     serverContext_->setEarlyDataSettings(
@@ -102,7 +103,7 @@ class HandshakeTest : public Test {
     serverContext_->setClientCertVerifier(verifier);
     std::vector<folly::ssl::X509UniquePtr> certVec;
     certVec.emplace_back(std::move(clientCert));
-    auto clientSelfCert = std::make_shared<SelfCertImpl<KeyType::RSA>>(
+    auto clientSelfCert = std::make_shared<OpenSSLSelfCertImpl<KeyType::RSA>>(
         std::move(clientKey), std::move(certVec));
     clientContext_->setClientCertificate(std::move(clientSelfCert));
 
