@@ -14,6 +14,7 @@
 #include <fizz/tool/FizzCommandCommon.h>
 #include <folly/FileUtil.h>
 #include <folly/String.h>
+#include <folly/base64.h>
 
 #include <fstream>
 
@@ -141,17 +142,22 @@ hpke::KEMId getKEMId(std::string kemStr) {
 
   // Input doesn't match any KEM id.
   throw std::runtime_error("Input doesn't match any KEM id");
-};
+}
 
-folly::Optional<folly::dynamic> readECHConfigsJson(std::string echFile) {
+std::string tryReadFile(const std::string& echFile) {
   if (echFile.empty()) {
     throw std::runtime_error("No file provided");
   }
 
-  std::string echConfigJson;
-  if (!folly::readFile(echFile.c_str(), echConfigJson)) {
+  std::string echConfigStr;
+  if (!folly::readFile(echFile.c_str(), echConfigStr)) {
     throw std::runtime_error("Unable to read file provided");
   }
+  return echConfigStr;
+}
+
+folly::Optional<folly::dynamic> readECHConfigsJson(std::string echFile) {
+  auto echConfigJson = tryReadFile(echFile);
 
   auto json = folly::parseJson(echConfigJson);
   if (!json.isObject()) {
@@ -164,8 +170,19 @@ folly::Optional<folly::dynamic> readECHConfigsJson(std::string echFile) {
   return json;
 }
 
-folly::Optional<std::vector<ech::ECHConfig>> parseECHConfigs(
-    folly::dynamic json) {
+folly::Optional<ech::ECHConfigList> parseECHConfigsBase64(
+    std::string echConfigListBase64) {
+  std::vector<ech::ECHConfig> echConfigs;
+  echConfigListBase64.erase(
+      std::remove(echConfigListBase64.begin(), echConfigListBase64.end(), '\n'),
+      echConfigListBase64.cend());
+  auto configBuf =
+      folly::IOBuf::copyBuffer(folly::base64Decode(echConfigListBase64));
+  folly::io::Cursor cursor(configBuf.get());
+  return decode<ech::ECHConfigList>(cursor);
+}
+
+folly::Optional<ech::ECHConfigList> parseECHConfigs(folly::dynamic json) {
   auto getKDFId = [](std::string kdfStr) {
     if (kdfStr == "Sha256") {
       return hpke::KDFId::Sha256;
@@ -256,7 +273,9 @@ folly::Optional<std::vector<ech::ECHConfig>> parseECHConfigs(
   if (echConfigs.empty()) {
     return folly::none;
   } else {
-    return echConfigs;
+    ech::ECHConfigList echConfigList;
+    echConfigList.configs = echConfigs;
+    return echConfigList;
   }
 }
 
