@@ -19,6 +19,8 @@
 #ifdef FIZZ_TOOL_ENABLE_ZSTD
 #include <fizz/compression/ZstdCertificateCompressor.h>
 #endif
+#include <fizz/protocol/CertUtils.h>
+#include <fizz/protocol/OpenSSLSelfCertImpl.h>
 #include <fizz/protocol/test/Utilities.h>
 #include <fizz/server/AsyncFizzServer.h>
 #include <fizz/server/SlidingBloomReplayCache.h>
@@ -92,8 +94,7 @@ void printUsage() {
     << "                          (For the X25519 key exchange, please specify the private key in hex on the first line,\n"
     << "                          (and the public key in hex on the second line.)\n"
 #ifdef FIZZ_TOOL_ENABLE_OQS
-    << " -hybridkex               (Use experimental hybrid key exchange. Currently the only supported named groups under\n"
-    << "                          this mode are secp384r1_bikel3 and secp521r1_x25519)\n"
+    << " -hybridkex               (Use experimental hybrid key exchange. See Types.h for available hybrid named groups.)\n"
 #endif
 #ifdef FIZZ_TOOL_ENABLE_IO_URING
     << " -io_uring                (use io_uring for I/O. Default: false)\n"
@@ -1126,7 +1127,7 @@ int fizzServerCommand(const std::vector<std::string>& args) {
     auto certData = fizz::test::createCert("fizz-self-signed", false, nullptr);
     std::vector<folly::ssl::X509UniquePtr> certChain;
     certChain.push_back(std::move(certData.cert));
-    auto cert = std::make_unique<SelfCertImpl<KeyType::P256>>(
+    auto cert = std::make_unique<OpenSSLSelfCertImpl<KeyType::P256>>(
         std::move(certData.key), std::move(certChain), compressors);
     certManager->addCert(std::move(cert), true);
   }
